summaryrefslogtreecommitdiffstats
path: root/connectivity/source/cpool/ZConnectionPool.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'connectivity/source/cpool/ZConnectionPool.cxx')
-rw-r--r--connectivity/source/cpool/ZConnectionPool.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/connectivity/source/cpool/ZConnectionPool.cxx b/connectivity/source/cpool/ZConnectionPool.cxx
index ddb80da0c02c..2a0609ed58e1 100644
--- a/connectivity/source/cpool/ZConnectionPool.cxx
+++ b/connectivity/source/cpool/ZConnectionPool.cxx
@@ -179,7 +179,7 @@ void SAL_CALL OConnectionPool::disposing( const css::lang::EventObject& Source )
{
MutexGuard aGuard(m_aMutex);
TActiveConnectionMap::iterator aIter = m_aActiveConnections.find(xConnection);
- OSL_ENSURE(aIter != m_aActiveConnections.end(),"OConnectionPool::disposing: Conenction wasn't in pool");
+ OSL_ENSURE(aIter != m_aActiveConnections.end(),"OConnectionPool::disposing: Connection wasn't in pool");
if(aIter != m_aActiveConnections.end())
{ // move the pooled connection back to the pool
aIter->second.aPos->second.nALiveCount = m_nALiveCount;
@@ -195,7 +195,7 @@ void SAL_CALL OConnectionPool::disposing( const css::lang::EventObject& Source )
Reference< XConnection> OConnectionPool::createNewConnection(const OUString& _rURL,const Sequence< PropertyValue >& _rInfo)
{
// create new pooled conenction
Reference< XPooledConnection > xPooledConnection = new ::connectivity::OPooledConnection(m_xDriver->connect(_rURL,_rInfo),m_xProxyFactory);
// get the new connection from the pooled connection
Reference<XConnection> xConnection = xPooledConnection->getConnection();
@@ -195,7 +195,7 @@ void SAL_CALL OConnectionPool::disposing( const css::lang::EventObject& Source )
Reference< XConnection> OConnectionPool::createNewConnection(const OUString& _rURL,const Sequence< PropertyValue >& _rInfo)
{
- // create new pooled conenction
+ // create new pooled connection
Reference< XPooledConnection > xPooledConnection = new ::connectivity::OPooledConnection(m_xDriver->connect(_rURL,_rInfo),m_xProxyFactory);
// get the new connection from the pooled connection